@@ -4,7 +4,6 @@ from django import forms
 
 
 class BLOBHostForm(forms.Form):
-    """BLOB Host Upload Form
-    """
+    """BLOB Host Upload Form"""
 
     file = forms.FileField(label="")
